AshGrant.Transformers.AddMaskingPreparation (AshGrant v0.14.1)

Copy Markdown View Source

Adds the masking preparation to resources that have field groups with masking.

When any field group defines mask and mask_with, this transformer adds AshGrant.Preparations.ApplyMasking as a resource-level preparation for read actions. The preparation applies masked values at runtime based on the actor's field group level.

Summary

Functions

after_compile?()

Callback implementation for Spark.Dsl.Transformer.after_compile?/0.